module emission
  !-----------------------------------------------------------------------
  !       purpose
  !       -------
  !       perform emissions needed for TM5 
  !
  !       interface
  !       ---------
  !       call declare_emission
  !       call emission_apply
  !       call free_emission
  !
  !       method
  !       ------
  !       subroutine declare_emission is called from trace0
  !       subroutine emission_apply   is called from source1
  !       subroutine free_emission    is called from trace_end
  !-----------------------------------------------------------------------
  use dims,      only: nregions

  implicit none

  private

  ! public routines:
  public   :: declare_emission, emission_apply, free_emission
  ! public types:

  ! public variables:
  public   :: sum_emission

  real, dimension(nregions)                                :: sum_emission


contains
   
  subroutine declare_emission
    !
    !       purpose
    !       -------
    !       allocate space needed to handle the emissions
    !
    !       interface
    !       ---------
    !       call declare_emission is called from trace0 (start and newmonth)
    !
    !       method
    !       ------
    !       dynamic allocation, depending on dimensions problem
    !       opening of daily input files
    !       reading monthly/yearly emissions
    !       
    !---------------------------------------------------------------------   
     
    implicit none

  end subroutine declare_emission


  subroutine emission_apply(region)
  !
    implicit none
    !___________________IO_____________________
    integer, intent(in)        :: region
    !___________________local__________________
    
  end subroutine emission_apply

  subroutine free_emission(budget_file)
    !
    !       purpose
    !       -------
    !       deallocate space needed to handle the emissions
    !
    !       interface
    !       ---------
    !       call free_emission is called from trace_end
    !
    !       method
    !       ------
    !       collecting budgets on coarser budget regions
    !       writing budget file
    !       deallocation of memory
    !       closing of input files
    !---------------------------------------------------------------------   
   implicit none
   ! IO
   character(len=*)                         :: budget_file
   ! local
   end subroutine free_emission

end module emission
