!  Defines tracers used in forward EnKF runs.

! Table of Contents:
!
! module chem_param
! end module chem_param

module chem_param
  !BOP
  ! !MODULE: chem_param
  ! !DESCRIPTION: 
  !  Defines tracers used by TM5.  In the forward run we define
  !  background and emission process tracers.
  !EOP

  use binas, only : xmair

  implicit none

  ! define specific data structures 

  ! definition of the chemistry: #reactions, order of species, etc.
  ! parameters needed for chemistry and rate constants 
  !

  ! nmark: number of 'marked' tracers 
  integer, parameter :: nmark = 1
  character(len=8),dimension(nmark) :: marknam = (/ 'ch4   ' /)

  ! ntrace: number of tracers for chemistry
  integer, parameter :: ntrace  = 12
  ! ntracet: number of transported tracers
  integer, parameter :: ntracet = 12
  ! ntrace_chem: non-transported tracers   
  integer, parameter :: ntrace_chem  = ntrace-ntracet
  ! maxtrace: total number of tracers
  integer, parameter :: maxtrace = ntrace + 0 

  !
  ! components numbers
  !
  !integer, parameter :: is0001=1      ! coal
  !integer, parameter :: is0002=2      ! oilgas
  !integer, parameter :: is0003=3      ! entferm
  !integer, parameter :: is0004=4      ! rice
  !integer, parameter :: is0005=5      ! biomass burning
  !integer, parameter :: is0006=6      ! waste
  !integer, parameter :: is0007=7      ! wetlands
  !integer, parameter :: is0008=8      ! wildan
  !integer, parameter :: is0009=9      ! termites
  !integer, parameter :: is0010=10      ! soil
  !integer, parameter :: is0011=11      ! ocean
  !integer, parameter :: is0012=12      ! background

  integer, parameter :: icoal=1          !coal
  integer, parameter :: ioilgas=2        !oilgas
  integer, parameter :: ientferm=3       !entferm
  integer, parameter :: irice=4          !rice
  integer, parameter :: ibb=5            !bb
  integer, parameter :: iwaste=6         !waste
  integer, parameter :: iwetl=7          !wetl
  integer, parameter :: iwildan=8        !wildan
  integer, parameter :: iterm=9          !term
  integer, parameter :: isoil=10          !soil
  integer, parameter :: iocean=11         !ocean
  integer, parameter :: ibgrnd=12         !bgrnd

  !
  ! additional fields used in chemistry routine alone 
  ! (more meteo-like files in units different from #/cm3)
  !
  integer,parameter                   :: n_extra = 0
  integer,parameter                   :: nstd    = 1
  integer, dimension(nstd), parameter :: istd    = (/ 1 /)
  !
  ! species name
  !
  character(len=8), dimension(maxtrace) :: names
  data names(icoal)          /'coal'/
  data names(ioilgas)        /'oilgas'/
  data names(ientferm)       /'entferm'/
  data names(irice)          /'rice'/
  data names(ibb)            /'bb'/
  data names(iwaste)         /'waste'/
  data names(iwetl)          /'wetl'/
  data names(iwildan)        /'wildan'/
  data names(iterm)          /'term'/
  data names(isoil)          /'soil'/
  data names(iocean)         /'ocean'/
  data names(ibgrnd)         /'bgrnd'/
  ! 
  ! some stuff for the budgets....
  !
  integer, parameter           :: njnum = 1
  integer, parameter           :: nreac = 1
  integer, parameter           :: nhet = 1
  integer, parameter           :: nreacw = 1
  character(len=8), dimension(njnum)  :: jnam   = (/'dummy   '/)
  character(len=8), dimension(nreac)  :: ratnam = (/'dummy   '/)
  character(len=8), dimension(nreacw) :: rwnam  = (/'dummy   '/)
  character(len=8), dimension(nhet) :: rhetnam  = (/'dummy   '/)

  ! molar weights of components

  real,    parameter :: xmh=1.0079
  real,    parameter :: xmn=14.0067
  real,    parameter :: xmc=12.01115
  real,    parameter :: xmch4=xmc+xmh*4.
  real,    parameter :: xms=32.064
  real,    parameter :: xmo=15.9994
  real,    parameter :: xmcl=35.453
  real,    parameter :: xmf=18.9984032
  real,    parameter :: xmh2o=xmh*2+xmo
  real,    parameter :: xmco2=xmc+2*xmo
  real,    parameter :: xmrn222=222.
  real,    parameter :: xmpb210=210.
  real,    parameter :: xmsf6= xms+6*xmf
  real,    parameter :: xmnmv=999. ! this is a dummy molecular mass

  real,dimension(maxtrace),parameter :: ra=(/xmch4,xmch4,xmch4,xmch4,xmch4,xmch4,   &
                                             xmch4,xmch4,xmch4,xmch4,xmch4,xmch4/)
  real,dimension(maxtrace),parameter      :: fscale = xmair/ra(:)
  real,dimension(maxtrace),parameter      :: uscale = (/1.e9,1.e9,1.e9,1.e9,1.e9,1.e9,   &
                                                        1.e9,1.e9,1.e9,1.e9,1.e9,1.e9/)

  !   fscale(ntrace): scaling factor for conversion of mixing ratios 
  !   in kg tracer per kg air to practical mixing ratio units (e.g. ppm)
  !   In this version: ratio of molecular weight  of tracer to that of air 

end module chem_param
