!### macro's #####################################################
!
#define IF_NOTOK_RETURN(action) if (status/=0) then; write (gol,'("in ",a)') rname; call goErr; action; return; end if
#define IF_ERROR_RETURN(action) if (status> 0) then; write (gol,'("in ",a)') rname; call goErr; action; return; end if
!
!#################################################################

module covariance_ch4

!-----------------------------------------------------------------------
!       purpose
!       -------
!       construct  flux component of 
!       covariance matrix for EnKF inversion 
!
!       interface
!       ---------
!       call covariance_ch4_compute
!
!       method
!       ------
!       subroutine is called from MakePriorUncertainty
!       in benkf_tools.F90
!
!-----------------------------------------------------------------------

implicit none

! --- const -------------------------
character(len=*), parameter  ::  mname = 'covariance_ch4'

private

! public routines:
public   :: covariance_ch4_compute

contains

subroutine covariance_ch4_compute(Q,parm_start,parm_end)

use GO,           only : gol, goErr, goPr, goLabel
use GO,           only : TrcFile, Init, Done, ReadRc
use global_data,  only : rcfile
use io_save,      only : readtm3hdf
use io_hdf,       only : io_write
use io_hdf,       only : DFNT_INT32, DFNT_CHAR, DFNT_FLOAT64, DFACC_CREATE, DFACC_WRITE
use go_string,    only : goNum2str

implicit none

integer                            :: parm_start,parm_end
real,dimension(:,:)                :: Q

character(len=*), parameter        :: rname = mname//'/covariance_ch4_compute'
type(TrcFile)                      :: rcF
integer                            :: nparms,i,j,status
character(len=256)                 :: covariance_file
real,dimension(:,:),allocatable    :: priorcov

call Init( rcF, rcfile, status)
IF_NOTOK_RETURN(status=1)
call ReadRc( rcF, 'ch4.covariance', covariance_file, status)
IF_NOTOK_RETURN(status=1)
call Done( rcF, status )
IF_NOTOK_RETURN(status=1)

nparms = parm_end-parm_start+1

allocate(priorcov(nparms,nparms))

call readtm3hdf(covariance_file,2,nparms,nparms,1,0,priorcov,'cov')


Q(parm_start:parm_end, parm_start:parm_end) = priorcov
!Q(parm_start:parm_end, parm_start:parm_end) = 1000.*priorcov

deallocate(priorcov)

end subroutine covariance_ch4_compute

!==================================================================

end module covariance_ch4
